@@ -22,6 +22,11 @@
 
 #include <stdlib.h> /* For type size_t */
 
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+
 /**
  * Allocates memory and always returns valid memory.
  * @size Amount of memory to allocate in bytes
@@ -115,4 +120,8 @@ char *px_strrstrip(char *string);
  */
 char *px_strstrip(char *string);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /*MISC_H_*/
